/* Définir les broches utilisées pour l'affichage */
#define LATCH_DIO 4
#define CLK_DIO 7
#define DATA_DIO 8

int etat_A3 = HIGH; 
int dernier_etat_A3 = HIGH;  

/* Initialiser les registres utilisés pour gérer le temps */  
unsigned long temps_actuel;      // Temps actuel en mS
unsigned long temps_precedent;   // Temps auquel le compteur a été actualisé la dernière fois

byte secondes = 0X00;           // Comptage des secondes

/* Dessins des nombres binaires de 0 à 59 à renseigner */
const byte SEGMENT_MAP[] = {0xFF,0xFD,0xFB,0xF9,0xF7,0xF5,0xF3,0xF1,0xEF,0xED,0xEB,0xE9,0xE7,0xE5,0xE3,0xE1,0xDF,0xDD,0xDB,0xD9,0xD7,0xD5,0xD3,0xD1,0xCF,0xCD,0xCB,0xC9,0xC7,0xC5,0xC3,0xC1,0xFE,0xFC,0xFA,0xF8,0xF6,0xF4,0xF2,0xF0,0xEE,0xEC,0xEA,0xE8,0xE6,0xE4,0xE2,0xE0,0xDE,0xDC,0xDA,0xD8,0xD6,0xD4,0xD2,0xD0,0xCE,0xCC,0xCA,0xC8};

/* Accès aux 4 afficheurs */
const byte SEGMENT_SELECT[] = {0xF1,0xF2,0xF4,0xF8};

void setup() {
  // put your setup code here, to run once:
  Serial.begin(9600);             // Initialiser port série
  
  /* Configurer les broches de sortie */
  pinMode(LATCH_DIO,OUTPUT);
  pinMode(CLK_DIO,OUTPUT);
  pinMode(DATA_DIO,OUTPUT);
  
  /* Configurer les broches d'entrée */
  pinMode(A3, INPUT);    // Définir Bouton A3 en entrée
  
  temps_actuel = millis();         // Temps actuel en mS
  temps_precedent = 0;             // Car on vient de démarrer l'Arduino
}

void loop() {
  // lecture du bouton
  
  etat_A3 = digitalRead(A3);
  if((etat_A3 != dernier_etat_A3) && (etat_A3 == LOW))
  {
    secondes ++;
    Serial.println("Nouveau compteur = " + String(secondes));
  }
  dernier_etat_A3 = etat_A3;
  
  WriteNumberToSegment(3, secondes);
}

/********  FONCTIONS  ********/

/* Ecrire un nombre entre 0 et 59 sur un des 3 digits de droite de l'afficheur */
void WriteNumberToSegment(byte Segment, byte Value)
{
  digitalWrite(LATCH_DIO,LOW);
  shiftOut(DATA_DIO, CLK_DIO, MSBFIRST, SEGMENT_MAP[Value]);
  shiftOut(DATA_DIO, CLK_DIO, MSBFIRST, SEGMENT_SELECT[Segment] );
  digitalWrite(LATCH_DIO,HIGH);    
}
